@@ -44,6 +44,9 @@ FAILEDOPERATION_DELETELASTBINDVPCRECORDFAILED = 'FailedOperation.DeleteLastBindV
 # 记录删除失败。
 FAILEDOPERATION_DELETERECORDFAILED = 'FailedOperation.DeleteRecordFailed'
 
+# 删除终端节点失败。
+FAILEDOPERATION_DELETEVPCENDPOINTFAILED = 'FailedOperation.DeleteVpcEndPointFailed'
+
 # 解析域删除失败。
 FAILEDOPERATION_DELETEZONEFAILED = 'FailedOperation.DeleteZoneFailed'
 
@@ -53,6 +56,9 @@ FAILEDOPERATION_MODIFYRECORDFAILED = 'FailedOperation.ModifyRecordFailed'
 # 私有域修改失败。
 FAILEDOPERATION_MODIFYZONEFAILED = 'FailedOperation.ModifyZoneFailed'
 
+# 记录更新失败
+FAILEDOPERATION_UPDATERECORDFAILED = 'FailedOperation.UpdateRecordFailed'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -65,6 +71,12 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 已经存在绑定的账号。
 INVALIDPARAMETER_ACCOUNTEXIST = 'InvalidParameter.AccountExist'
 
+# 终端节点已经绑定了转发规则。
+INVALIDPARAMETER_ENDPOINTBINDFORWARDRULE = 'InvalidParameter.EndPointBindForwardRule'
+
+# 终端节点不存在。
+INVALIDPARAMETER_ENDPOINTNOTEXISTS = 'InvalidParameter.EndPointNotExists'
+
 # 非法CIDR。
 INVALIDPARAMETER_ILLEGALCIDR = 'InvalidParameter.IllegalCidr'
 
@@ -128,6 +140,9 @@ INVALIDPARAMETER_RECORDTXTCOUNTEXCEED = 'InvalidParameter.RecordTXTCountExceed'
 # 当前记录类型不支持权重。
 INVALIDPARAMETER_RECORDUNSUPPORTWEIGHT = 'InvalidParameter.RecordUnsupportWeight'
 
+# 唯一id不存在
+INVALIDPARAMETER_UNIQUEIDNOTEXIST = 'InvalidParameter.UniqueIdNotExist'
+
 # VPC已绑定其它解析域。
 INVALIDPARAMETER_VPCBINDED = 'InvalidParameter.VpcBinded'
 
